<?php 


/*

Scratch 1.4 License

License

Scratch 1.4 Software

Copyright (c) 2009 Massachusetts Institute of Technology

Scratch is developed by the Lifelong Kindergarten group at the MIT Media Lab.

See http://scratch.mit.edu

The Scratch logo and the Scratch cat are trademarks of MIT.

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and accompanying documentation and media files (the "Software") to distribute the Software, including the right to use, copy, publish, or distribute copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies of the Software.

If the software is published or distributed, the following statement shall be displayed in a visible place on a website or on distribution media such as CDs:

  Scratch is developed by the Lifelong Kindergarten group at the MIT Media Lab.

  See http://scratch.mit.edu

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


*/





//////////////////////////////////////////////////////////////
//  Scratch plugin filtering
//
//  Moodle filter based on mediaplugin filter. Adapted by P.Dring 23/9/2010
//
//  filter/scratchplugin/filter.php

//

//////////////////////////////////////////////////////////////



/// This is the filtering function itself.  It accepts the
/// courseid and the text to be filtered (in HTML form).



require_once($CFG->libdir.'/filelib.php');



function scratch_filter($courseid, $text) {

    global $CFG;



    // You should never modify parameters passed to a method or function, it's BAD practice. Create a copy instead.

    // The reason is that you must always be able to refer to the original parameter that was passed.

    // For this reason, I changed $text = preg_replace(..,..,$text) into $newtext = preg.... (NICOLAS CONNAULT)

    // Thanks to Pablo Etcheverry for pointing this out! MDL-10177



    // We're using the UFO technique for flash to attain XHTML Strict 1.0

    // See: http://www.bobbyvandersluis.com/ufo/

    if (!is_string($text)) {

        // non string data can not be filtered anyway

        return $text;

    }

    $newtext = $text; // fullclone is slow and not needed here



    if ($CFG->filter_scratchplugin_enable) {

        $search = '/<a.*?href="([^<]+\.sb)"[^>]*>.*?<\/a>/is';

        $newtext = preg_replace_callback($search, 'scratchplugin_filter_callback', $newtext);

    }





    if (is_null($newtext) or $newtext === $text) {

        // error or not filtered

        return $text;

    }

    return $newtext;

}



///===========================

/// callback filter functions



function scratchplugin_filter_callback($link) {

    global $CFG, $THEME;

	$newurl = str_replace($CFG->wwwroot . "/", "../../", $link[1]);

	$path = explode("/", $link[1]);

	$filename = $path[count($path) - 1];
	
	$width = 482;
	$height = 387;
	$center = $CFG->filter_scratchplugin_center;
    $showlink = $CFG->filter_scratchplugin_showlink;

	return '

	<div ' . ($CFG->filter_scratchplugin_center?'align="center"' : '') . '>

	<applet id="ProjectApplet" style="display:block" code="ScratchApplet" codebase="' . $CFG->wwwroot . '/filter/scratch/" archive="ScratchApplet.jar" height="' . $height . '" width="' . $width . '">

	<param name="project" value="' . $newurl . '">

	
	
	<param name="autostart" value="' . 
	
	($CFG->filter_scratchplugin_autostart? 'true' : 'false') . 
	
	'">

	<h3><a href="http://www.java.com/getjava/">Install Java</a> to view this project right on your browser!</h3></applet>

	<p>

	<small>
	Scratch is developed by the Lifelong Kindergarten Group at the MIT Media Lab.  See <a href="http://scratch.mit.edu">http://scratch.mit.edu</a></small></p>
    ' . ($showlink?	'<a href="' . $newurl .'"><img src="' . $CFG->wwwroot . '/filter/scratch/download.gif" width="16px" height="16px"/> ' . $filename . '</a></div>' : '');

}

?>

